@@ -304,10 +304,21 @@ def _check_args(func: ConfigKey, args: ConfigValue):
 
 def _get_funcs(func: typing.Callable) -> typing.List[typing.Callable]:
     """Get a list of functions `func` may be referring to."""
-    if inspect.isclass(func) and func.__new__ is object.__new__:
-        funcs = [func.__init__]
-    elif inspect.isclass(func):
-        funcs = [func.__init__, func.__new__]
+    if inspect.isclass(func):
+        funcs = []
+        if func.__init__ not in (b.__init__ for b in func.__bases__):
+            funcs.append(func.__init__)
+        if func.__new__ not in (b.__new__ for b in func.__bases__):
+            funcs.append(func.__new__)
+        if len(funcs) == 0:
+            # NOTE: An implicit configuration like this may lead to duplicate configurations.
+            # This happens when the user defines a seperate configuration for a child and parent
+            # object that share the same initiation. Since there is no difference between their
+            # initiation functions, the configuration for them is duplicated.
+            raise KeyError(
+                f"The initiation for `{func}` is only implicitly defined. "
+                "Please use only explicit configurations."
+            )
     else:
         funcs = [func]
     return [_unwrap(f) for f in funcs]
@@ -318,8 +329,8 @@ def _get_funcs_to_trace(
 ) -> typing.List[typing.Tuple[typing.Callable, typing.Callable]]:
     """Get functions to trace along with their corresponding function configuration key."""
     funcs = [k for k in config.keys() if not _is_builtin(k)]
-    message = "`__code__` isn't unique"
     items = [(k, v) for v in funcs for k in _get_funcs(v)]
+    message = "`__code__` isn't unique"
     assert len(set(f.__code__ for f, _ in items)) == len(items), message
     return items
 
@@ -344,8 +355,13 @@ def _update_trace_globals():
     _call_once.cache_clear()
 
 
-def add(config: Config):
-    """Add to the global configuration."""
+def add(config: Config, overwrite: bool = False):
+    """Add to the global configuration.
+
+    Args:
+        config
+        overwrite: Iff `True` then configurations can be overwritten.
+    """
     global _config
     global _code_to_func
 
@@ -353,8 +369,12 @@ def add(config: Config):
 
     for key, value in config.items():
         key = _unwrap(key)
+        _get_funcs(key)  # NOTE: Check `key` before adding it
         if key in _config:
-            _config[key] = Args({**_config[key], **value})
+            update = Args({**_config[key], **value})
+            if not overwrite and len(update) != len(_config[key]) + len(value):
+                raise ValueError(f"Attempting to overwrite `{key}` configuration.")
+            _config[key] = update
         else:
             _config[key] = value.copy()
 
